Introduction
============

This is the documentation for the aioamqp module.


Prerequisites
-------------

Aioamqp works only with python >= 3.3 using asyncio library.
If your are using Python 3.3 you'll have to install asyncio from pypi, but asyncio is now included in python 3.4 standard library.

Installation
------------

You can install the most recent aioamqp release from pypi using pip or easy_install::

    pip install aioamqp
    easy_install aioamqp
